@@ -467,6 +467,8 @@ def flatten(values):
     # flatten nested lists of np.ndarray to np.ndarray
     return np.concatenate(list(_flatten(values)))
 
+def flatten_list(list_of_lists):
+    return [val for sublist in list(list_of_lists) for val in sublist]
 
 def unflatten(flat_values, prototype):
     if isinstance(prototype, list):
@@ -812,8 +814,19 @@ def array_pop(X, idx):
 def isdigit(s):
     """
     check if the number is a digit, including if it has a decimal place in it
+    Or is numeric
     :param s:
     :return:
     """
-    return s.replace('.','',1).isdigit()
+    return s.replace('.','',1).replace('-', '').isdigit()
 
+
+def split_list(cur_list, func):
+    list_true = []
+    list_false = []
+    for w in cur_list:
+        if func(w):
+            list_true.append(w)
+        else:
+            list_false.append(w)
+    return list_true, list_false
\ No newline at end of file
